@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2004 Adam Hooper
+ *  Copyright © 2004 Adam Hooper
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-page-info-extension.c,v 1.19 2006/03/25 20:53:34 jframeau Exp $
+ *  $Id: ephy-page-info-extension.c 1376 2006-09-13 19:01:42Z chpe $
  */
 
 #include "config.h"
@@ -82,7 +82,7 @@ ephy_page_info_extension_get_type (void)
 GType
 ephy_page_info_extension_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphyPageInfoExtensionClass),
 		NULL, /* base_init */
@@ -95,7 +95,7 @@ ephy_page_info_extension_register_type (GTypeModule *module)
 		(GInstanceInitFunc) ephy_page_info_extension_init
 	};
 
-	static const GInterfaceInfo extension_info =
+	const GInterfaceInfo extension_info =
 	{
 		(GInterfaceInitFunc) ephy_page_info_extension_iface_init,
 		NULL,
