@@ -1,5 +1,5 @@
 /*
-*  Copyright (C) 2005 Raphaël Slinckx <raphael@slinckx.net>
+*  Copyright © 2005 Raphaël Slinckx <raphael@slinckx.net>
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
-*  $Id: rss-ui.c,v 1.10 2005/12/22 22:32:46 rslinckx Exp $
+*  $Id: rss-ui.c 1376 2006-09-13 19:01:42Z chpe $
 */
 
 #include "config.h"
@@ -717,7 +717,7 @@ rss_ui_get_type (void)
 GType
 rss_ui_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (RssUIClass),
 		NULL, /* base_init */
