@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,12 +16,10 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-sample2-extension.c,v 1.4 2004/05/30 12:23:13 chpe Exp $
+ *  $Id: ephy-sample2-extension.c 1376 2006-09-13 19:01:42Z chpe $
  */
 
-#ifdef HAVE_CONFIG_H
 #include "config.h"
-#endif
 
 #include "ephy-sample2-extension.h"
 #include "mozilla-sample.h"
@@ -29,18 +27,16 @@
 
 #include <epiphany/ephy-extension.h>
 
+#include <glib/gi18n-lib.h>
 #include <gmodule.h>
 
 #define EPHY_SAMPLE2_EXTENSION_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EPHY_TYPE_SAMPLE2_EXTENSION, EphySample2ExtensionPrivate))
 
-struct EphySample2ExtensionPrivate
+struct _EphySample2ExtensionPrivate
 {
+	gpointer dummy;
 };
 
-static void ephy_sample2_extension_class_init	(EphySample2ExtensionClass *klass);
-static void ephy_sample2_extension_iface_init	(EphyExtensionIface *iface);
-static void ephy_sample2_extension_init		(EphySample2Extension *extension);
-
 enum
 {
 	PROP_0
@@ -50,6 +46,116 @@ static GObjectClass *parent_class = NULL;
 
 static GType type = 0;
 
+static void
+ephy_sample2_extension_init (EphySample2Extension *extension)
+{
+	extension->priv = EPHY_SAMPLE2_EXTENSION_GET_PRIVATE (extension);
+
+	LOG ("EphySample2Extension initialising");
+}
+
+static void
+ephy_sample2_extension_finalize (GObject *object)
+{
+/*
+	EphySample2Extension *extension = EPHY_SAMPLE2_EXTENSION (object);
+*/
+	LOG ("EphySample2Extension finalising");
+
+	G_OBJECT_CLASS (parent_class)->finalize (object);
+}
+
+static gboolean
+dom_mouse_down_cb (EphyEmbed *embed,
+		   EphyEmbedEvent *event,
+		   EphySample2Extension *extension)
+{
+	gpointer dom_event;
+
+	dom_event = ephy_embed_event_get_dom_event (event);
+
+	LOG ("DOM Event %p", dom_event);
+
+	mozilla_do_something (dom_event);
+
+	return FALSE;
+}
+
+static void
+impl_attach_window (EphyExtension *ext,
+		    EphyWindow *window)
+{
+	GtkWidget *notebook;
+
+	LOG ("EphySample2Extension attach_window");
+
+	notebook = ephy_window_get_notebook (window);
+}
+
+static void
+impl_detach_window (EphyExtension *ext,
+		    EphyWindow *window)
+{
+	GtkWidget *notebook;
+
+	LOG ("EphySample2Extension detach_window");
+
+	notebook = ephy_window_get_notebook (window);
+}
+
+static void
+impl_attach_tab (EphyExtension *ext,
+		 EphyWindow *window,
+		 EphyTab *tab)
+{
+	EphyEmbed *embed;
+
+	LOG ("impl_attach_tab");
+
+	embed = ephy_tab_get_embed (tab);
+	g_return_if_fail (EPHY_IS_EMBED (embed));
+
+	g_signal_connect (embed, "ge_dom_mouse_down",
+			  G_CALLBACK (dom_mouse_down_cb), ext);
+}
+
+static void
+impl_detach_tab (EphyExtension *ext,
+		 EphyWindow *window,
+		 EphyTab *tab)
+{
+	EphyEmbed *embed;
+
+	LOG ("impl_detach_tab");
+
+	embed = ephy_tab_get_embed (tab);
+	g_return_if_fail (EPHY_IS_EMBED (embed));
+
+	g_signal_handlers_disconnect_by_func
+		(embed, G_CALLBACK (dom_mouse_down_cb), ext);
+}
+
+static void
+ephy_sample2_extension_iface_init (EphyExtensionIface *iface)
+{
+	iface->attach_window = impl_attach_window;
+	iface->detach_window = impl_detach_window;
+	iface->attach_tab = impl_attach_tab;
+	iface->detach_tab = impl_detach_tab;
+}
+
+static void
+ephy_sample2_extension_class_init (EphySample2ExtensionClass *klass)
+{
+	GObjectClass *object_class = G_OBJECT_CLASS (klass);
+
+	parent_class = g_type_class_peek_parent (klass);
+
+	object_class->finalize = ephy_sample2_extension_finalize;
+
+	g_type_class_add_private (object_class, sizeof (EphySample2ExtensionPrivate));
+}
+
 GType
 ephy_sample2_extension_get_type (void)
 {
@@ -59,7 +165,7 @@ ephy_sample2_extension_get_type (void)
 GType
 ephy_sample2_extension_register_type (GTypeModule *module)
 {
-	static const GTypeInfo our_info =
+	const GTypeInfo our_info =
 	{
 		sizeof (EphySample2ExtensionClass),
 		NULL, /* base_init */
@@ -72,7 +178,7 @@ ephy_sample2_extension_register_type (GTypeModule *module)
 		(GInstanceInitFunc) ephy_sample2_extension_init
 	};
 
-	static const GInterfaceInfo extension_info =
+	const GInterfaceInfo extension_info =
 	{
 		(GInterfaceInitFunc) ephy_sample2_extension_iface_init,
 		NULL,
@@ -91,120 +197,3 @@ ephy_sample2_extension_register_type (GTypeModule *module)
 
 	return type;
 }
-
-static void
-ephy_sample2_extension_init (EphySample2Extension *extension)
-{
-	extension->priv = EPHY_SAMPLE2_EXTENSION_GET_PRIVATE (extension);
-
-	LOG ("EphySample2Extension initialising")
-}
-
-static void
-ephy_sample2_extension_finalize (GObject *object)
-{
-/*
-	EphySample2Extension *extension = EPHY_SAMPLE2_EXTENSION (object);
-*/
-	LOG ("EphySample2Extension finalising")
-
-	G_OBJECT_CLASS (parent_class)->finalize (object);
-}
-
-static gboolean
-dom_mouse_down_cb (EphyEmbed *embed,
-		   EphyEmbedEvent *event,
-		   EphySample2Extension *extension)
-{
-	gpointer dom_event;
-
-	dom_event = ephy_embed_event_get_dom_event (event);
-	LOG ("DOM Event %p", dom_event)
-
-	mozilla_do_something (dom_event);
-
-	return FALSE;
-}
-
-static void
-tab_added_cb (GtkWidget *notebook,
-	      EphyTab *tab,
-	      EphySample2Extension *extension)
-{
-	EphyEmbed *embed;
-
-	g_return_if_fail (EPHY_IS_TAB (tab));
-
-	embed = ephy_tab_get_embed (tab);
-	g_return_if_fail (EPHY_IS_EMBED (embed));
-
-	g_signal_connect (embed, "ge_dom_mouse_down",
-			  G_CALLBACK (dom_mouse_down_cb), extension);
-}
-
-static void
-tab_removed_cb (EphyEmbed *notebook,
-		EphyTab *tab,
-		EphySample2Extension *extension)
-{
-	EphyEmbed *embed;
-
-	g_return_if_fail (EPHY_IS_TAB (tab));
-
-	embed = ephy_tab_get_embed (tab);
-	g_return_if_fail (EPHY_IS_EMBED (embed));
-
-	g_signal_handlers_disconnect_by_func
-		(embed, G_CALLBACK (dom_mouse_down_cb), extension);
-}
-
-static void
-impl_attach_window (EphyExtension *ext,
-		    EphyWindow *window)
-{
-	GtkWidget *notebook;
-
-	LOG ("EphySample2Extension attach_window")
-
-	notebook = ephy_window_get_notebook (window);
-
-	g_signal_connect_after (notebook, "tab_added",
-				G_CALLBACK (tab_added_cb), ext);
-	g_signal_connect_after (notebook, "tab_removed",
-				G_CALLBACK (tab_removed_cb), ext);
-}
-
-static void
-impl_detach_window (EphyExtension *ext,
-		    EphyWindow *window)
-{
-	GtkWidget *notebook;
-
-	LOG ("EphySample2Extension detach_window")
-
-	notebook = ephy_window_get_notebook (window);
-
-	g_signal_handlers_disconnect_by_func
-		(notebook, G_CALLBACK (tab_added_cb), ext);
-	g_signal_handlers_disconnect_by_func
-		(notebook, G_CALLBACK (tab_removed_cb), ext);
-}
-
-static void
-ephy_sample2_extension_iface_init (EphyExtensionIface *iface)
-{
-	iface->attach_window = impl_attach_window;
-	iface->detach_window = impl_detach_window;
-}
-
-static void
-ephy_sample2_extension_class_init (EphySample2ExtensionClass *klass)
-{
-	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-
-	parent_class = g_type_class_peek_parent (klass);
-
-	object_class->finalize = ephy_sample2_extension_finalize;
-
-	g_type_class_add_private (object_class, sizeof (EphySample2ExtensionPrivate));
-}
